Index: trunk/var/www/info/alkis/alkisinlaybaurecht.php
===================================================================
--- trunk/var/www/info/alkis/alkisinlaybaurecht.php	(revision 102)
+++ trunk/var/www/info/alkis/alkisinlaybaurecht.php	(revision 105)
@@ -4,9 +4,6 @@
 
 	Version:
-	21.09.2010  Neu
-	22.09.2010  Feintuning, sql-Limit
-	11.10.2010  simplify Geometrie: Schwellwert Verschneidung Flaeche>0 anpassen
-	14.12.2010  Pfad zur Conf
 	17.12.2010  Astrid Emde: Prepared Statements (pg_query -> pg_prepare + pg_execute)
+	26.07.2011  debug	
 */
 ini_set('error_reporting', 'E_ALL & ~ E_NOTICE');
@@ -37,4 +34,5 @@
 $con = pg_connect("host=".$dbhost." port=" .$dbport." dbname=".$dbname." user=".$dbuser." password=".$dbpass);
 if (!$con) echo "<p class='err'>Fehler beim Verbinden der DB</p>\n";
+if ($debug > 1) {echo "<p class='err'>DB=".$dbname.", user=".$dbuser."</p>";}
 
 // wie View "baurecht"
@@ -45,5 +43,5 @@
 $sql.="LEFT JOIN ax_bauraumoderbodenordnungsrecht_artderfestlegung a ON r.artderfestlegung = a.wert ";
 $sql.="LEFT JOIN ax_dienststelle d ON r.land = d.land AND r.stelle = d.stelle ";
-$sql.="WHERE r.gml_id= $1;";
+$sql.="WHERE r.gml_id= $1 ;";
 
 $v = array($gmlid);
@@ -52,7 +50,6 @@
 
 if (!$res) {
-	echo "\n<p class='err'>Fehler bei Baurecht:<br>";
-	echo "\n<br>SQL=<br>\n".$sql;
-	echo "\n</p>\n";
+	echo "\n<p class='err'>Fehler bei Baurecht.</p>\n";
+	if ($debug > 2) {echo "<p class='err'>SQL=<br>".$sql."<br>$1 = ".$gmlid."</p>\n";}
 }
 echo "\n<h2><img src='ico/Gericht.ico' width='16' height='16' alt=''> Bau-, Raum- oder Bodenordnungsrecht</h2>\n";
Index: trunk/var/www/info/alkis/alkisinlayausk.php
===================================================================
--- trunk/var/www/info/alkis/alkisinlayausk.php	(revision 102)
+++ trunk/var/www/info/alkis/alkisinlayausk.php	(revision 105)
@@ -12,11 +12,6 @@
 
 	Version:
-	11.10.2010  Umbau alkisausk zu inlay-Version
-	12.10.2010  korrekturen
-	14.12.2010  Pfad zur Conf
-	17.12.2010  Astrid Emde: Prepared Statements (pg_query -> pg_prepare + pg_execute)
-	25.01.2011  F. JÃ€ger: Adressen (Lage mit HsNr) zum FS anzeigen	
-					https://trac.wheregroup.com/PostNAS/ticket/6
 	01.02.2011  *Left* Join - Fehlertoleranz bei unvollstaendigen Schluesseltabellen
+	25.07.2011  PostNAS 0.5/0.6 Versionen unterscheiden
 
 	ToDo:  Link im neuen Fenster erzwingen (Javascript?), statt _blank = tab
@@ -112,5 +107,9 @@
 $sql.="JOIN ax_lagebezeichnungmithausnummer l ON v.beziehung_zu=l.gml_id "; // Strassennamen JOIN
 $sql.="LEFT JOIN ax_lagebezeichnungkatalogeintrag s ON l.kreis=s.kreis AND l.gemeinde=s.gemeinde ";
-$sql.="AND to_char(l.lage, 'FM00000') = lpad(s.lage,5,'0') ";
+if ($dbvers=="05") {
+	$sql.="AND to_char(l.lage, 'FM00000') = lpad(s.lage,5,'0') ";
+} else { // ab PostNAS 0.6
+	$sql.="AND l.lage=s.lage ";
+}
 $sql.="WHERE v.beziehung_von= $1 "; // id FS";
 $sql.="AND v.beziehungsart='weistAuf' ";
Index: trunk/var/www/info/alkis/alkisausk.php
===================================================================
--- trunk/var/www/info/alkis/alkisausk.php	(revision 102)
+++ trunk/var/www/info/alkis/alkisausk.php	(revision 105)
@@ -18,4 +18,5 @@
 					https://trac.wheregroup.com/PostNAS/ticket/6
 	01.02.2011  *Left* Join - Fehlertoleranz bei unvollstaendigen Schluesseltabellen
+	25.07.2011  PostNAS 0.5/0.6 Versionen unterscheiden
 */
 ini_set('error_reporting', 'E_ALL');
@@ -142,5 +143,9 @@
 $sql.="JOIN ax_lagebezeichnungmithausnummer l ON v.beziehung_zu=l.gml_id "; // Strassennamen JOIN
 $sql.="LEFT JOIN ax_lagebezeichnungkatalogeintrag s ON l.kreis=s.kreis AND l.gemeinde=s.gemeinde ";
-$sql.="AND to_char(l.lage, 'FM00000') = lpad(s.lage,5,'0') ";
+if ($dbvers=="05") {
+	$sql.="AND to_char(l.lage, 'FM00000') = lpad(s.lage,5,'0') ";
+} else { // ab PostNAS 0.6
+	$sql.="AND l.lage = s.lage ";
+}
 $sql.="WHERE v.beziehung_von= $1 "; // id FS";
 $sql.="AND v.beziehungsart='weistAuf' ";
Index: trunk/var/www/info/alkis/alkisgebaeudenw.php
===================================================================
--- trunk/var/www/info/alkis/alkisgebaeudenw.php	(revision 102)
+++ trunk/var/www/info/alkis/alkisgebaeudenw.php	(revision 105)
@@ -4,15 +4,7 @@
 
 	Version:
-	15.09.2010  Function "buchungsart" durch JOIN ersetzt
-	21.09.2010  vergessenen Parameter &style und Kommentar entfernt
-	01.10.2010  Geschoss-Anzahl
-	14.12.2010  Pfad zur Conf
-	17.12.2010  Astrid Emde: Prepared Statements (pg_query -> pg_prepare + pg_execute)
-	25.01.2011  F.J.: Strassennamen zur Hausnummer
-					https://trac.wheregroup.com/PostNAS/ticket/6
-	26.01.2011  Space in leere td
-
-	01.02.2011  *Left* Join - Fehlertoleranz bei unvollstaendigen Schluesseltabellen
-	07.02.2011 
+	07.02.2011  *Left* Join - Fehlertoleranz bei unvollstaendigen Schluesseltabellen
+	25.07.2011  PostNAS 0.5/0.6 Versionen unterscheiden	
+	
 	ToDo: lfd.Nr. der NebengebÃ€ude alternativ zur Hausnummer anzeigen.
 		Dazu aber Join auf ax_lagebezeichnungmitpseudonummer notwendig.
@@ -105,5 +97,5 @@
 		echo "\n\t<tr>";
 			echo "\n\t\t<td title='Gemarkung'>";
-			if  ($shaowkey) {
+			if  ($showkey) {
 				echo "<span class='key'>".$gmkgnr."</span><br>";
 			}
@@ -157,6 +149,9 @@
 // StraÃen-Name
 $sqlg.="LEFT JOIN ax_lagebezeichnungkatalogeintrag s ON l.kreis=s.kreis AND l.gemeinde=s.gemeinde ";
-$sqlg.="AND to_char(l.lage, 'FM00000') = lpad(s.lage,5,'0') ";
-
+if ($dbvers=="05") {
+	$sqlg.="AND to_char(l.lage, 'FM00000') = lpad(s.lage,5,'0') ";
+} else { // ab PostNAS 06.
+	$sqlg.="AND l.lage=s.lage ";
+}
 // Alternativ zur Hauptgebaeude-Hausnummer auch die Nebengebaeude-Pseudo-Nummern suchen?
 // $sqlg.="LEFT JOIN ax_lagebezeichnungmitpseudonummer p ON ... ";
Index: trunk/var/www/info/alkis/alkis_conf_location.php
===================================================================
--- trunk/var/www/info/alkis/alkis_conf_location.php	(revision 102)
+++ trunk/var/www/info/alkis/alkis_conf_location.php	(revision 105)
@@ -6,4 +6,5 @@
 	Version:
 	14.12.2010 zentrale Anpassung des Pfades
+	25.07.2011 PostNAS 0.5/0.6 Versionen unterscheiden
 */
 # relativ:
@@ -12,4 +13,5 @@
 # absolut:
 #  Hier: Entwicklungs-Version
-require_once("/data/conf/alkis_entw_conf.php");
+require_once("/data/conf/alkis_www_conf.php");
+$dbname = $dbpre.$dbvers.$gkz;  // Prefix + Konverter-Version + Mandant
 ?>
Index: trunk/var/www/info/alkis/alkisfsnw.php
===================================================================
--- trunk/var/www/info/alkis/alkisfsnw.php	(revision 102)
+++ trunk/var/www/info/alkis/alkisfsnw.php	(revision 105)
@@ -6,20 +6,15 @@
 
 	Version:
-	30.09.2010  noprint
-	09.11.2010  Nutzung, ehem. php-Functions hier integriert
-	10.11.2010  Felder nutzung.zustand und nutzung.name
-	14.12.2010  Pfad zur Conf
-	17.12.2010  Astrid Emde: Prepared Statements (pg_query -> pg_prepare + pg_execute)
-	04.01.2011  Frank JÃ€ger: verkuerzte Nutzungsart-Zeilen mit Icon. Tabelle Gebiet/Lage/Nutzung 4spaltig.
-	05.01.2011  Korrektur der Fallunterscheidung "Funktion", auch "Vegetationsmerkmal", Title auf "Zustand".
-	26.01.2011  Space in leere td
-	01.02.2011  *Left* Join - Fehlertoleranz bei unvollstaendigen Schluesseltabellen
 	11.07.2011  Ersetzen $self durch $_SERVER['PHP_SELF']."?"
+	25.07.2011  PostNAS 0.5/0.6 Versionen unterscheiden
+	26.07.2011  debug	
+	
 	ToDo:
+	- Nach Umstellung auf PostNAS 0.6 die Sonderbehandlung Version 0.5 entfernen 
 	- EntschlÃŒsseln "Bahnkategorie" bei Bahnverkehr, "OberflÃ€chenmaterial" bei Unland
 	  Dazu evtl. diese Felder ins Classfld verschieben (Meta-Tabellen!)
 	- NamNum >bestehtAusRechtsverhaeltnissenZu> NamNum
 */
-ini_set('error_reporting', 'E_ALL & ~ E_NOTICE');
+//ini_set('error_reporting', 'E_ALL & ~ E_NOTICE');
 session_start();
 $gkz=urldecode($_REQUEST["gkz"]);
@@ -65,4 +60,5 @@
 $con = pg_connect("host=".$dbhost." port=" .$dbport." dbname=".$dbname." user=".$dbuser." password=".$dbpass);
 if (!$con) echo "<p class='err'>Fehler beim Verbinden der DB</p>\n";
+if ($debug > 1) {echo "<p class='err'>DB=".$dbname.", user=".$dbuser."</p>";}
 
 // F L U R S T U E C K
@@ -90,5 +86,5 @@
 } else {
 	echo "<p class='err'>Fehler! Kein Treffer fuer gml_id=".$gmlid."</p>";
-	//echo "<p class='err'>SQL=".$sql."</p>";
+	if ($debug > 2) {echo "<p class='err'>SQL=<br>".$sql."<br>$1 = ".$gmlid."</p>";}
 }
 // Balken
@@ -186,20 +182,14 @@
 $sql.="JOIN ax_lagebezeichnungmithausnummer  l ON v.beziehung_zu=l.gml_id "; // Strassennamen JOIN
 $sql.="JOIN ax_lagebezeichnungkatalogeintrag s ON l.kreis=s.kreis AND l.gemeinde=s.gemeinde ";
-$sql.="AND to_char(l.lage, 'FM00000') = lpad(s.lage,5,'0') ";
+if ($dbvers=="05") { // 25.07.11
+	$sql.="AND to_char(l.lage, 'FM00000') = lpad(s.lage,5,'0') ";
+} else { // ab PostNAS 0.6
+	$sql.="AND l.lage = s.lage ";
+}
 $sql.="WHERE v.beziehung_von= $1 "; // id FS";
 $sql.="AND v.beziehungsart='weistAuf' ";
 $sql.="ORDER BY l.gemeinde, l.lage, l.hausnummer;";
-
 // Theoretisch JOIN notwendig ÃŒber den kompletten SchlÃŒssel bestehend aus land+regierungsbezirk+kreis+gemeinde+lage
 // bei einem SekundÃ€rbestand fÃŒr eine Gemeinde oder einen Kreis reicht dies hier:
-
-//$sql.="JOIN  ax_lagebezeichnungkatalogeintrag s ON l.gemeinde=s.gemeinde AND l.lage=s.lage ";
-// Problem: ax_lagebezeichnungkatalogeintrag.lage  ist char,
-//          ax_lagebezeichnungmithausnummer.lage   ist integer,
-
-// cast() scheitert weil auch nicht numerische Inhalte
-//$sql.="JOIN  ax_lagebezeichnungkatalogeintrag s ON l.gemeinde=s.gemeinde AND l.lage=cast(s.lage AS integer) ";
-
-// http://www.postgresql.org/docs/8.3/static/functions-formatting.html
 
 $v = array($gmlid);
@@ -223,5 +213,7 @@
 		echo $sname."&nbsp;".$row["hausnummer"]."</td>";
 		echo "\n\t<td>\n\t\t<p class='nwlink noprint'>";
-			echo "\n\t\t\t<a title='Lagebezeichnung mit Hausnummer' href='alkislage.php?gkz=".$gkz."&amp;ltyp=m&amp;gmlid=".$row["gml_id"]."'>Lage ";
+			echo "\n\t\t\t<a title='Lagebezeichnung mit Hausnummer' href='alkislage.php?gkz=".$gkz."&amp;ltyp=m&amp;gmlid=".$row["gml_id"];
+			if ($showkey) {echo "&amp;showkey=j";}
+			echo "'>Lage ";
 			echo "<img src='ico/Lage_mit_Haus.ico' width='16' height='16' alt=''></a>";
 		echo "\n\t\t</p>\n\t</td>";
@@ -238,10 +230,9 @@
 $sql.="JOIN ax_lagebezeichnungohnehausnummer l ON l.gml_id=v.beziehung_zu ";
 $sql.="LEFT JOIN ax_lagebezeichnungkatalogeintrag s ON l.kreis=s.kreis AND l.gemeinde=s.gemeinde ";
-//	$sql.="AND l.lage=s.lage ";
-// hier beide .lage als Char(5)
-//  in ax_lagebezeichnungKatalogeintrag mit fÃŒhrenden Nullen
-//  in ax_lagebezeichnungOhneHausnummer jedoch ohne fÃŒhrende Nullen
-$sql.="AND l.lage::text=trim(leading '0' from s.lage) ";
-//	$sql.="AND cast(l.lage AS integer)=cast(s.lage AS integer) "; // Fehlversuch, auch nicht-numerische Inhalte
+if ($dbvers=="05") {
+	$sql.="AND l.lage::text=trim(leading '0' from s.lage) ";
+} else { // ab PostNAS 0.6
+	$sql.="AND l.lage = s.lage ";
+}
 $sql.="WHERE v.beziehung_von= $1 "; // id FS";
 $sql.="AND   v.beziehungsart='zeigtAuf';"; //ORDER?
@@ -262,6 +253,7 @@
 			echo "\n\t<td class='lr'>".$gewann."</td>";
 			echo "\n\t<td>\n\t\t<p class='nwlink noprint'>";
-				echo "\n\t\t\t<a title='Lagebezeichnung Ohne Hausnummer' href='alkislage.php?gkz=".$gkz."&amp;ltyp=o&amp;gmlid=".$lgml."'>";
-				echo "\n\t\t\tLage <img src='ico/Lage_Gewanne.ico' width='16' height='16' alt=''></a>";
+				echo "\n\t\t\t<a title='Lagebezeichnung Ohne Hausnummer' href='alkislage.php?gkz=".$gkz."&amp;ltyp=o&amp;gmlid=".$lgml;
+				if ($showkey) {echo "&amp;showkey=j";}				
+				echo "'>\n\t\t\tLage <img src='ico/Lage_Gewanne.ico' width='16' height='16' alt=''></a>";
 			echo "\n\t\t</p>\n\t</td>";
 		echo "\n</tr>";
@@ -278,6 +270,7 @@
 			echo $row["bezeichnung"]."</td>";
 			echo "\n\t<td>\n\t\t<p class='nwlink noprint'>";
-				echo "\n\t\t\t<a title='Lagebezeichnung Ohne Hausnummer' href='alkislage.php?gkz=".$gkz."&amp;ltyp=o&amp;gmlid=".$lgml."'>";
-				echo "\n\t\t\tLage <img src='ico/Lage_an_Strasse.ico' width='16' height='16' alt=''>\n\t\t\t</a>";
+				echo "\n\t\t\t<a title='Lagebezeichnung Ohne Hausnummer' href='alkislage.php?gkz=".$gkz."&amp;ltyp=o&amp;gmlid=".$lgml;
+				if ($showkey) {echo "&amp;showkey=j";}				
+				echo "'>\n\t\t\tLage <img src='ico/Lage_an_Strasse.ico' width='16' height='16' alt=''>\n\t\t\t</a>";
 			echo "\n\t\t</p>\n\t</td>";
 		echo "\n</tr>";
@@ -416,5 +409,5 @@
 			echo "\n\t\t\t<a href='alkisgebaeudenw.php?gkz=".$gkz."&amp;gmlid=".$gmlid;
 			if ($idanzeige) {echo "&amp;id=j";}
-			if ($showkey)   {echo "&amp;id=j";}
+			if ($showkey) {echo "&amp;showkey=j";}
 			echo "' title='Geb&auml;udenachweis'>Geb&auml;ude <img src='ico/Haus.ico' width='16' height='16' alt=''></a>";
 		echo "\n\t\t</p>";

Index: trunk/var/www/info/alkis/alkislage.php
===================================================================
--- trunk/var/www/info/alkis/alkislage.php	(revision 102)
+++ trunk/var/www/info/alkis/alkislage.php	(revision 105)
@@ -13,12 +13,12 @@
 	07.02.2011  JOIN ax_gemeinde auch ueber regierungsbezirk
 	11.07.2011  Ersetzen $self durch $_SERVER['PHP_SELF']."?"
+	25.07.2011  PostNAS 0.5/0.6 Versionen unterscheiden
 	ToDo: Entschluesseln Kreis usw.
 */
-ini_set('error_reporting', 'E_ALL & ~ E_NOTICE');
+//ini_set('error_reporting', 'E_ALL & ~ E_NOTICE');
 session_start();
 $gkz=urldecode($_REQUEST["gkz"]);
 require_once("alkis_conf_location.php");
-if ($auth == "mapbender") {
-	// Bindung an Mapbender-Authentifizierung
+if ($auth == "mapbender") { // Bindung an Mapbender-Authentifizierung
 	require_once($mapbender);
 }
@@ -92,18 +92,24 @@
 $sql.="LEFT JOIN ax_kreisregion k ON l.land=k.land AND l.regierungsbezirk=k.regierungsbezirk AND l.kreis=k.kreis ";
 $sql.="LEFT JOIN ax_lagebezeichnungkatalogeintrag s ";
-// Besonderheit: unterschiedliche Feldformate und Fuellungen!!!
-switch ($ltyp) {
-	case "o": //"Ohne HsNr"
-		// hier beide .lage als Char(5)
-		//  in ax_lagebezeichnungKatalogeintrag mit fÃŒhrenden Nullen
-		//  in ax_lagebezeichnungOhneHausnummer jedoch ohne fÃŒhrende Nullen
-		$sql.="ON l.land=s.land AND l.regierungsbezirk=s.regierungsbezirk AND l.kreis=s.kreis AND l.gemeinde=s.gemeinde AND l.lage=trim(leading '0' from s.lage) ";
-	break;
-	default: // "Mit HsNr" + "mit PseudoNr"
-		// ax_LagebezeichnungKatalogeintrag.lage   ist char,
-		// ax_LagebezeichnungMitHausnummer.lage    ist integer,
-		// ax_lagebezeichnungMitPseudonummer.lage  ist integer,
-		$sql.="ON l.land=s.land AND l.regierungsbezirk=s.regierungsbezirk AND l.kreis=s.kreis AND l.gemeinde=s.gemeinde AND to_char(l.lage, 'FM00000')=s.lage ";
-	break;
+
+if ($dbvers == "05") { // bis PostNAS 0.5
+	// Besonderheit: unterschiedliche Feldformate und Fuellungen!!!
+	// +++ Nach vollstaendiger Umstellung diesen Programmteil entfernen 
+	switch ($ltyp) {
+		case "o": //"Ohne HsNr"
+			// hier beide .lage als Char(5)
+			//  in ax_lagebezeichnungKatalogeintrag mit fÃŒhrenden Nullen
+			//  in ax_lagebezeichnungOhneHausnummer jedoch ohne fÃŒhrende Nullen
+			$sql.="ON l.land=s.land AND l.regierungsbezirk=s.regierungsbezirk AND l.kreis=s.kreis AND l.gemeinde=s.gemeinde AND l.lage=trim(leading '0' from s.lage) ";
+		break;
+		default: // "Mit HsNr" + "mit PseudoNr"
+			// ax_LagebezeichnungKatalogeintrag.lage   ist char,
+			// ax_LagebezeichnungMitHausnummer.lage    ist integer,
+			// ax_lagebezeichnungMitPseudonummer.lage  ist integer,
+			$sql.="ON l.land=s.land AND l.regierungsbezirk=s.regierungsbezirk AND l.kreis=s.kreis AND l.gemeinde=s.gemeinde AND to_char(l.lage, 'FM00000')=s.lage ";
+		break;
+	}
+} else { // ab PostNAS 0.6 char(5) mit fuehr.Nullen
+	$sql.="ON l.land=s.land AND l.regierungsbezirk=s.regierungsbezirk AND l.kreis=s.kreis AND l.gemeinde=s.gemeinde AND l.lage=s.lage ";
 }
 $sql.="WHERE l.gml_id= $1;";